function [info_read] = read_voltage_info(f_dir,n_tag,cases)
% [voltage_info] = read_voltage_info(f_dir)
%
% This function takes in the directory name as input and extracts the
% voltage information from the name of the file.
%
% Input parameters:
% f_dir= Location/directory of the .wfm files
% begin_name= The first nametag of the file 
%(Hint: if you are currently located in the directory of the .wfm files you
%       may also use pwd as in: >>volt = read_voltage_info(pwd)  
% )
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Current state of the project and change history.
%
%	Created by:	R. Obaid
%	Created on:	07/30/2011
%
%	Version: 1.0
%	Modified by: 
%	Edited on:	
%	  
%
% If you type 'help read_voltage_info' on the Matlab command window, you
% will see the help documentaiton.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cd(f_dir);
begin_name=n_tag;
full_name=strcat(begin_name,'*','.wfm');

temp_name=dir(full_name);
fileNum=length(temp_name);

info_read=struct('fName',[],'voltage_info',[],'pos_info',[],...
    'unique_voltage',[],'unique_num',[],'same_v_index',[],'unique_pos',[],...
    'same_pos_index',[]);
    
    


%--------------------------------------------------------------------------
%In the fileName the string has the following structure:
%       Type-MCPver-VoltageTag-ScanTag-ChanNum.wfm
%
%   So to isolate the VoltageTag, one can extract the string 
%between the second '-' from the left and the second '-' from the
%right.
%   This action is necessary as Delta V can have a negative value which may 
%create problem in using the regular expression of MATLAB as minus sign is
%same as '-' delimiter used in the filenaming standard.
%--------------------------------------------------------------------------

if cases==1
    for i=1:fileNum
        fileName=temp_name(i).name;
    
        fName{i}=fileName;
    
        temp_val=regexp(fileName,'-');

        s_len=length(temp_val);

        volt_set=fileName((temp_val(2)+1):(temp_val(s_len-1)-1));
   
        voltage_string=regexp(volt_set,'_','split');
    
        voltage_value(i,:)=str2double(voltage_string);


    end


    voltage_info=voltage_value;

    %Finding unique values, row-wise.
    [~,same_v_index,~]=unique(voltage_value,'rows');

    n=length(same_v_index);

    for i=1:n
        unique_voltage(i,:)=voltage_value(same_v_index(i),:);
    end
    info_read.unique_num=n;
    info_read.voltage_info=voltage_info;
    info_read.unique_voltage=unique_voltage;
    info_read.same_v_index=same_v_index;
    info_read.fName=fName;
    
    
    
    
elseif cases==2

    for i=1:fileNum
        fileName=temp_name(i).name;
    
        fName{i}=fileName;
    
        temp_val=regexp(fileName,'-');

        s_len=length(temp_val);

        volt_set=fileName((temp_val(2)+1):(temp_val(s_len-2)-1));
   
        voltage_string=regexp(volt_set,'_','split');
    
        voltage_value(i,:)=str2double(voltage_string);

        pos_set=fileName((temp_val(3)+1):temp_val(s_len-1)-1);
        
        pos_string=regexp(pos_set,'_','split');
        
        pos_value(i,:)=str2double(pos_string(1:2));

    end


    voltage_info=voltage_value;
    pos_info=pos_value;

    %Finding unique values, row-wise.
    [unique_voltage,same_v_index,~]=unique(voltage_value,'rows');
    
    [~,same_pos_index,~]=unique(pos_value,'rows');
    
    n_pos=length(same_pos_index);
    

    for i=1:n_pos
        unique_pos(i,:)=pos_value(same_pos_index(i),:);
    end
    
    info_read.unique_num=n_pos;
    info_read.voltage_info=voltage_info;
    info_read.pos_info=pos_info;
    info_read.unique_voltage=unique_voltage;
    info_read.unique_pos=unique_pos;
    info_read.same_v_index=same_v_index;
    info_read.same_pos_index=same_pos_index;
    info_read.fName=fName;


end





  
    

end

